Attempts to determine if the input data is from a discrete distribution. Will
return true if the data type is of type integer or there are non-unique
values.
Usage
isDiscrete(x)
Arguments
x
a vector which should be determined if discrete or not.
Value
the best judgement of whether or not the data was discrete